#!/usr/bin/env python3
#Python version of PDRK, written by Xin TAO (USTC), 2017-03-27
# Original Matlab version: Hua-sheng XIE (IFTS-ZJU), 2014
# http://hsxie.me/codes/pdrk/

import numpy as np
from setbc import setbc

def Zpade(z):
    b,c = setbc()
    print(np.sum(b*c**2))
    tmp = b/(z-c)
    return np.sum(tmp)

def es1d(file, kv):
    data = np.loadtxt(file, skiprows=1)
    S, col = data.shape

    if col != 5:
        print('Wrong input data !!!')

    qs = data[:,0]
    ms = data[:,1]
    ns0 = data[:,2]
    Ts =  data[:,3]
    vs0 = data[:,4]

    vts=np.sqrt(2*Ts/ms) # thermal velocity
    lambdaDs=np.sqrt(Ts/(ns0*qs**2)) # Deybe length
    kDs=1/lambdaDs;
    wps=np.sqrt(ns0*qs**2/ms) # plasma frequency

    J=12
    b,c = setbc(J)
    
    SJ = S*J

    csj = np.zeros(SJ, dtype=np.complex)
    bsj = np.zeros(SJ, dtype=np.complex)

    size_k = kv.size
    wmat = np.zeros((size_k,SJ), dtype=np.complex)
    
    for ik in np.arange(size_k):
        k = kv[ik]
        sj = 0
        for s in np.arange(S):
            for j in np.arange(J):
                csj[sj]=k*(c[j]*vts[s]+vs0[s])
                bsj[sj]=vts[s]*b[j]*c[j]*(kDs[s]**2/k)
                sj=sj+1

                M = np.zeros((SJ,SJ), dtype=np.complex)

        for sj in np.arange(SJ):
            M[sj,:]=-bsj[sj]
            M[sj,sj]=-bsj[sj]+csj[sj]

        omega,v=np.linalg.eig(M)
        sort_ind = np.argsort(omega.imag)[::-1]
        w = omega[sort_ind]

        wmat[ik,:] = w
        
    return wmat


if __name__ == '__main__':

    kv = np.arange(0.4, 0.01, -0.02)
    wmat = es1d('es1d.in', kv)

    import matplotlib.pyplot as plt

    plt.close('all')

    plt.subplot(1,2,1)
    plt.plot(kv, wmat[:,0].imag)
    plt.plot(kv, wmat[:,1].imag)
    plt.plot(kv, wmat[:,2].imag)

    plt.subplot(1,2,2)
    plt.plot(kv, wmat[:,0].real, '--')
    plt.plot(kv, wmat[:,1].real, '.')
    plt.plot(kv, wmat[:,2].real, '.')

    plt.show()



